@@ -120,7 +120,7 @@ extern "C" int exec(LObject* imyKey, XEvent xev) {
             amarok.play();
             if ( (play = amarok.isPlaying()) != "" ) {
 	       dname += ": ";
-	       dname += (amarok.isPlaying()).latin1();
+	       dname += play.latin1();
             }
         }
         else if (comm.upper() == "AMAROK_PAUSE") {
@@ -133,21 +133,22 @@ extern "C" int exec(LObject* imyKey, XEvent xev) {
             amarok.playPause();
             if ( (play = amarok.isPlaying()) != "" ) {
 	       dname += ": ";
-	       dname += (amarok.isPlaying()).latin1();
+	       dname += play.latin1();
             }
     	}
 	else if (comm.upper() == "AMAROK_BACK") {
             amarok.back();
             if ( (play = amarok.isPlaying()) != "" ) {
 	       dname += ": ";
-	       dname += (amarok.isPlaying()).latin1();
+	       dname += play.latin1();
             }
         }
 	else if (comm.upper() == "AMAROK_FORWARD") {
             amarok.forward();
             if ( (play = amarok.isPlaying()) != "" ) {
 	       dname += ": ";
-	       dname += (amarok.isPlaying()).latin1();
+	       dname += play.latin1();
+	       
             }
 	}
 	else if (comm.upper() == "AMAROK_SEEK") {
@@ -156,7 +157,7 @@ extern "C" int exec(LObject* imyKey, XEvent xev) {
 	       amarok.seek(s);
                if ( (play = amarok.isPlaying()) != "" ) {
                   dname += ": ";
-                  dname += (amarok.isPlaying()).latin1();
+                  dname += play.latin1();
                }
             }
 	}
@@ -169,7 +170,7 @@ extern "C" int exec(LObject* imyKey, XEvent xev) {
 	       amarok.enableRandomMode(arg);
                if ( (play = amarok.isPlaying()) != "" ) {
                   dname += ": ";
-                  dname += (amarok.isPlaying()).latin1();
+                  dname += play.latin1();
                }
             }
 	}
