@@ -41,8 +41,8 @@ using namespace std;
 #include "konqplugin.h"
 
 /** These are required */
-#define NUM_MACROS 28
-string konq_symbols[NUM_MACROS] = { "KONQUEROR", "KONQUEROR_SETURL", "KONQUEROR_BACK", "KONQUEROR_QUIT", "KONQUEROR_BREAKOFF_CURRENT_TAB", "KONQUEROR_DUPLICATE_WINDOW", "KONQUEROR_DUPLICATE_CURRENT_TAB", "KONQUEROR_FORWARD", "KONQUEROR_FULLSCREEN", "KONQUEROR_SIDEBAR", "KONQUEROR_HOME", "KONQUEROR_PRINT", "KONQUEROR_STOP", "KONQUEROR_REFRESH", "KONQUEROR_REMOVE_CURRENT_TAB", "KONQUEROR_REMOVEVIEW", "KONQUEROR_RELOAD", "KONQUEROR_SPLITVIEW_H", "KONQUEROR_SPLITVIEW_V", "KONQUEROR_NEWTAB", "KONQUEROR_NEXTTAB", "KONQUEROR_PREVTAB", "KONQUEROR_TABMOVE_LEFT", "KONQUEROR_TABMOVE_RIGHT", "KONQUEROR_TRASH", "KONQUEROR_UNDO", "KONQUEROR_UP", "KONQUEROR_BOOKMARK" };
+#define NUM_MACROS 29
+string konq_symbols[NUM_MACROS] = { "KONQUEROR", "KONQUEROR_SETURL", "KONQUEROR_BACK", "KONQUEROR_QUIT", "KONQUEROR_BREAKOFF_CURRENT_TAB", "KONQUEROR_DUPLICATE_WINDOW", "KONQUEROR_DUPLICATE_CURRENT_TAB", "KONQUEROR_FORWARD", "KONQUEROR_FULLSCREEN", "KONQUEROR_SIDEBAR", "KONQUEROR_HOME", "KONQUEROR_PRINT", "KONQUEROR_STOP", "KONQUEROR_REFRESH", "KONQUEROR_REMOVE_CURRENT_TAB", "KONQUEROR_REMOVEVIEW", "KONQUEROR_RELOAD", "KONQUEROR_RELOAD_ALL_TABS", "KONQUEROR_SPLITVIEW_H", "KONQUEROR_SPLITVIEW_V", "KONQUEROR_NEWTAB", "KONQUEROR_NEXTTAB", "KONQUEROR_PREVTAB", "KONQUEROR_TABMOVE_LEFT", "KONQUEROR_TABMOVE_RIGHT", "KONQUEROR_TRASH", "KONQUEROR_UNDO", "KONQUEROR_UP", "KONQUEROR_BOOKMARK" };
 macro_info* konq_macinfo = NULL;
 identifier_info* konq_idinfo = NULL;
 bool verbose = false;
@@ -102,6 +102,7 @@ extern "C" int exec(LObject* imyKey, XEvent xev) {
              command.getMacroType() == "KONQUEROR_STOP" ||
              command.getMacroType() == "KONQUEROR_REFRESH" ||
              command.getMacroType() == "KONQUEROR_RELOAD" ||
+	     command.getMacroType() == "KONQUEROR_RELOAD_ALL_TABS" ||
              command.getMacroType() == "KONQUEROR_NEWTAB" ||
              command.getMacroType() == "KONQUEROR_NEXTTAB" ||
              command.getMacroType() == "KONQUEROR_PREVTAB" ||
@@ -183,7 +184,7 @@ bool macroKONQUEROR(LCommand& command) {
 	}
         QString comm;
 	if (args.size() == 1) {
-           if (command.getCommand() == "KONQUEROR_SETURL") {
+           if (command.getMacroType() == "KONQUEROR_SETURL") {
               comm = "SETURL";
            } else
 	      comm = QString((args[0]).c_str());
@@ -215,6 +216,9 @@ bool macroKONQUEROR(LCommand& command) {
 	   else if ( comm.upper() == "REFRESH" || comm.upper() == "RELOAD" ) {
 	      konq.refresh();
 	   }
+	   else if ( comm.upper() == "RELOAD_ALL_TABS" ) {
+	      konq.reload_all_tabs();
+	   }
 	   else if ( comm.upper() == "NEWTAB" ) {
 	      konq.newtab();
 	   }
@@ -280,7 +284,6 @@ bool macroKONQUEROR(LCommand& command) {
 	   } else {
 	      if (verbose) {
 		cerr << comm << " is an unknown KONQUEROR macro argument." << endl;
-		cerr << "Valid arguments are: BACK, FORWARD, REFRESH or RELOAD, NEWTAB" << endl;
 	      }
 	      return false;
 	   }
